@@ -25,7 +25,7 @@ import astropy.io.votable as votable
 
 from ..exceptions import (RemoteServiceError, TableParseError,
                           InvalidQueryError, LoginError)
-from ..utils import commons, system_tools
+from ..utils import commons, system_tools, url_helpers
 from ..utils.process_asyncs import async_to_sync
 from ..query import QueryWithLogin
 from . import conf
@@ -105,7 +105,7 @@ class AlmaClass(QueryWithLogin):
                                 science=science, **kwargs)
 
     def query_async(self, payload, cache=True, public=True, science=True,
-                    view_format='raw'):
+                    view_format='raw', get_query_payload=False, **kwargs):
         """
         Perform a generic query with user-specified payload
 
@@ -125,6 +125,7 @@ class AlmaClass(QueryWithLogin):
 
         url = urljoin(self._get_dataarchive_url(), 'aq/')
 
+        payload.update(kwargs)
         payload.update({'result_view': view_format, 'format': 'VOTABLE',
                         'download': 'true'})
         if public:
@@ -134,8 +135,12 @@ class AlmaClass(QueryWithLogin):
 
         self.validate_query(payload)
 
+        if get_query_payload:
+            return payload
+
         response = self._request('GET', url, params=payload,
                                  timeout=self.TIMEOUT, cache=cache)
+        self._last_response = response
         response.raise_for_status()
 
         return response
@@ -234,9 +239,16 @@ class AlmaClass(QueryWithLogin):
         self._staging_log['initial_response'] = response
         log.debug("First response URL: {0}".format(response.url))
         if response.status_code == 405:
-            raise HTTPError("Received an error 405: this may indicate you "
-                            "have already staged the data.  Try downloading "
-                            "the file URLs directly with download_files.")
+            if hasattr(self,'_last_successful_staging_log'):
+                log.warning("Error 405 received.  If you have previously staged "
+                            "the same UIDs, the result returned is probably "
+                            "correct, otherwise you may need to create a fresh "
+                            "astroquery.Alma instance.")
+                return self._last_successful_staging_log['result']
+            else:
+                raise HTTPError("Received an error 405: this may indicate you "
+                                "have already staged the data.  Try downloading "
+                                "the file URLs directly with download_files.")
         response.raise_for_status()
 
         if 'j_spring_cas_security_check' in response.url:
@@ -247,7 +259,7 @@ class AlmaClass(QueryWithLogin):
                                      timeout=self.TIMEOUT, cache=False)
             self._staging_log['initial_response'] = response
             if 'j_spring_cas_security_check' in response.url:
-                log.warn("Staging request was not successful.  Try again?")
+                log.warning("Staging request was not successful.  Try again?")
             response.raise_for_status()
 
         if 'j_spring_cas_security_check' in response.url:
@@ -262,7 +274,7 @@ class AlmaClass(QueryWithLogin):
 
         # Submit a request for the specific request ID identified above
         submission_url = urljoin(self.dataarchive_url,
-                                 os.path.join('rh/submission', request_id))
+                                 url_helpers.join('rh/submission', request_id))
         log.debug("Submission URL: {0}".format(submission_url))
         self._staging_log['submission_url'] = submission_url
         staging_submission = self._request('GET', submission_url, cache=True)
@@ -282,8 +294,8 @@ class AlmaClass(QueryWithLogin):
         has_completed = False
         while not has_completed:
             time.sleep(1)
-            summary = self._request('GET', os.path.join(data_page_url,
-                                                        'summary'),
+            summary = self._request('GET', url_helpers.join(data_page_url,
+                                                            'summary'),
                                     cache=False)
             summary.raise_for_status()
             print(".", end='')
@@ -294,7 +306,7 @@ class AlmaClass(QueryWithLogin):
         summary.raise_for_status()
         self._staging_log['json_data'] = json_data = summary.json()
 
-        username = self._username if hasattr(self, '_username') else 'anonymous'
+        username = self.USERNAME if self.USERNAME else 'anonymous'
 
         # templates:
         # https://almascience.eso.org/dataPortal/requests/keflavich/946895898/ALMA/
@@ -310,6 +322,8 @@ class AlmaClass(QueryWithLogin):
                                                     ))
         tbl = self._json_summary_to_table(json_data, base_url=base_url)
         self._staging_log['result'] = tbl
+        self._staging_log['file_urls'] = tbl['URL']
+        self._last_successful_staging_log = self._staging_log
 
         return tbl
 
@@ -389,12 +403,32 @@ class AlmaClass(QueryWithLogin):
         if not verbose:
             commons.suppress_vo_warnings()
 
-        tf = six.BytesIO(response.content)
+        fixed_content = self._hack_band_vofix(response.content)
+        tf = six.BytesIO(fixed_content)
         vo_tree = votable.parse(tf, pedantic=False, invalid='mask')
         first_table = vo_tree.get_first_table()
         table = first_table.to_table(use_names_over_ids=True)
         return table
 
+    def _hack_band_vofix(self, text):
+        """
+        Hack to fix an error in the ALMA votables present in most 2016 queries.
+
+        The problem is that this entry:
+        '      <FIELD name="Band" datatype="char" ID="32817" xtype="adql:VARCHAR" arraysize="0*">\r',
+        has an invalid ``arraysize`` entry.
+        """
+        lines = text.split(b"\n")
+        newlines = []
+
+        for ln in lines:
+            if b'FIELD name="Band"' in ln:
+                ln = ln.replace(b'arraysize="0*"', b'arraysize="1*"')
+            newlines.append(ln)
+
+        return b"\n".join(newlines)
+
+
     def _login(self, username=None, store_password=False,
                reenter_password=False):
         """
@@ -414,7 +448,7 @@ class AlmaClass(QueryWithLogin):
         """
 
         if username is None:
-            if self.USERNAME == "":
+            if not self.USERNAME:
                 raise LoginError("If you do not pass a username to login(), "
                                  "you should configure a default one!")
             else:
@@ -437,8 +471,8 @@ class AlmaClass(QueryWithLogin):
 
         if password_from_keyring is None:
             if system_tools.in_ipynb():
-                log.warn("You may be using an ipython notebook:"
-                         " the password form will appear in your terminal.")
+                log.warning("You may be using an ipython notebook:"
+                            " the password form will appear in your terminal.")
             password = getpass.getpass("{0}, enter your ALMA password:"
                                        "\n".format(username))
         else:
@@ -463,7 +497,7 @@ class AlmaClass(QueryWithLogin):
 
         if authenticated:
             log.info("Authentication successful!")
-            self._username = username
+            self.USERNAME = username
         else:
             log.exception("Authentication failed!")
         # When authenticated, save password in keyring if needed
@@ -839,7 +873,7 @@ class AlmaClass(QueryWithLogin):
                             "size={0} uid={1} url={2}"
                             .format(size, uid, columns['URL'][-1]))
                 else:
-                    log.warn("Access to {0} is not authorized.".format(uid))
+                    log.warning("Access to {0} is not authorized.".format(uid))
             elif len(tds) > 3 and tds[2].find('a'):
                 # Old Style
                 href = tds[2].find('a')
@@ -897,10 +931,9 @@ class AlmaClass(QueryWithLogin):
                 # https://almascience.eso.org/dataPortal/requests/keflavich/946895898/ALMA/
                 # 2013.1.00308.S_uid___A001_X196_X93_001_of_001.tar/2013.1.00308.S_uid___A001_X196_X93_001_of_001.tar
                 # uid___A002_X9ee74a_X26f0/2013.1.00308.S_uid___A002_X9ee74a_X26f0.asdm.sdm.tar
-                url = os.path.join(base_url,
-                                   entry['file_key'],
-                                   entry['file_name'],
-                                   )
+                url = url_helpers.join(base_url,
+                                       entry['file_key'],
+                                       entry['file_name'])
                 if 'null' in url:
                     raise ValueError("The URL {0} was created containing "
                                      "'null', which is invalid.".format(url))
