@@ -3,7 +3,8 @@ CosmoSim Database Query Tool
 -----------------------------
 .. topic:: Revision History
 
-    Access to all cosmological simulations stored in the CosmoSim database, via the uws service.
+    Access to all cosmological simulations stored in the CosmoSim database,
+    via the uws service.
 
     http://www.cosmosim.org/uws/query
 
@@ -12,6 +13,7 @@ CosmoSim Database Query Tool
 
 from astropy import config as _config
 
+
 class Conf(_config.ConfigNamespace):
     """
     Configuration parameters for `astroquery.cosmosim`.
@@ -19,19 +21,19 @@ class Conf(_config.ConfigNamespace):
 
     query_url = _config.ConfigItem(
         ['http://www.cosmosim.org/uws/query'],
-        'CosmoSim UWS query URL'
-        )
+        'CosmoSim UWS query URL.')
     schema_url = _config.ConfigItem(
         ['http://www.cosmosim.org/query/account/databases/json'],
-        'CosmoSim json query URL for generating database schema'
-        )
+        'CosmoSim json query URL for generating database schema.')
     timeout = _config.ConfigItem(
         60.0,
-        'Timeout for CosmoSim query'
-        )
-    
+        'Timeout for CosmoSim query.')
+    username = _config.ConfigItem(
+        "",
+        'Optional default username for CosmoSim database.')
+
 conf = Conf()
 
-from .core import CosmoSim,CosmoSimClass
+from .core import CosmoSim, CosmoSimClass
 
 __all__ = ['CosmoSim', 'CosmoSimClass', 'Conf', 'conf']
