@@ -203,8 +203,8 @@ class EsoClass(QueryWithLogin):
 
         if password_from_keyring is None:
             if system_tools.in_ipynb():
-                log.warn("You may be using an ipython notebook:"
-                         " the password form will appear in your terminal.")
+                log.warning("You may be using an ipython notebook:"
+                            " the password form will appear in your terminal.")
             password = getpass.getpass("{0}, enter your ESO password:\n"
                                        .format(username))
         else:
@@ -269,8 +269,14 @@ class EsoClass(QueryWithLogin):
             self._survey_list = []
             collections_table = root.find('table', id='collections_table')
             other_collections = root.find('select', id='collection_name_option')
-            for element in (collections_table.findAll('input', type='checkbox') +
-                            other_collections.findAll('option')):
+            # it is possible to have empty collections or other collections...
+            collection_elts = (collections_table.findAll('input', type='checkbox')
+                               if collections_table is not None
+                               else [])
+            other_elts = (other_collections.findAll('option')
+                          if other_collections is not None
+                          else [])
+            for element in (collection_elts + other_elts):
                 if 'value' in element.attrs:
                     survey = element.attrs['value']
                     if survey and survey not in self._survey_list and 'Any' not in survey:
@@ -285,9 +291,10 @@ class EsoClass(QueryWithLogin):
         Parameters
         ----------
         survey : string or list
-            Name of the survey(s) to query.  Should beone or more of the names
-            returned by `list_surveys()`.  If specified as a string, should be
-            a comma-separated list of survey names.
+            Name of the survey(s) to query.  Should beone or more of the
+            names returned by `~astroquery.eso.EsoClass.list_surveys`.  If
+            specified as a string, should be a comma-separated list of
+            survey names.
         cache : bool
             Cache the response for faster subsequent retrieval
 
@@ -333,7 +340,6 @@ class EsoClass(QueryWithLogin):
             else:
                 warnings.warn("Query returned no results", NoResultsWarning)
 
-
     def query_instrument(self, instrument, column_filters={}, columns=[],
                          open_form=False, help=False, cache=True, **kwargs):
         """
@@ -343,7 +349,7 @@ class EsoClass(QueryWithLogin):
         ----------
         instrument : string
             Name of the instrument to query, one of the names returned by
-            `list_instruments()`.
+            `~astroquery.eso.EsoClass.list_instruments`.
         column_filters : dict
             Constraints applied to the query.
         columns : list of strings
@@ -353,9 +359,10 @@ class EsoClass(QueryWithLogin):
             for the requested instrument.
         help : bool
             If `True`, prints all the parameters accepted in
-            `column_filters` and `columns` for the requested `instrument`.
+            ``column_filters`` and ``columns`` for the requested
+            ``instrument``.
         cache : bool
-            Cache the response for faster subsequent retrieval
+            Cache the response for faster subsequent retrieval.
 
         Returns
         -------
@@ -402,8 +409,11 @@ class EsoClass(QueryWithLogin):
                 query_dict["max_rows_returned"] = self.ROW_LIMIT
             else:
                 query_dict["max_rows_returned"] = 10000
-            instrument_response = self._activate_form(
-                instrument_form, form_index=0, inputs=query_dict, cache=cache)
+            # used to be form 0, but now there's a new 'logout' form at the top
+            instrument_response = self._activate_form(instrument_form,
+                                                      form_index=-1,
+                                                      inputs=query_dict,
+                                                      cache=cache)
 
             content = instrument_response.content
             # First line is always garbage
@@ -489,7 +499,7 @@ class EsoClass(QueryWithLogin):
 
     def data_retrieval(self, datasets):
         """
-        DEPRECATED: see `retrieve_datasets`
+        DEPRECATED: see ``retrieve_datasets``
         """
 
         warnings.warn("data_retrieval has been replaced with retrieve_data",
