@@ -15,16 +15,13 @@ class Conf(_config.ConfigNamespace):
 
     url = _config.ConfigItem(
         'http://fermi.gsfc.nasa.gov/cgi-bin/ssc/LAT/LATDataQuery.cgi',
-        'Fermi query URL.'
-        )
+        'Fermi query URL.')
     timeout = _config.ConfigItem(
         60,
-        'Time limit for connecting to Fermi server.'
-        )
+        'Time limit for connecting to Fermi server.')
     retrieval_timeout = _config.ConfigItem(
         120,
-        'Time limit for retrieving a data file once it has been located.'
-        )
+        'Time limit for retrieving a data file once it has been located.')
 
 conf = Conf()
 
@@ -36,4 +33,5 @@ __all__ = ['FermiLAT', 'FermiLATClass',
            ]
 
 import warnings
-warnings.warn("Experimental: Fermi-LAT has not yet been refactored to have its API match the rest of astroquery.")
+warnings.warn("Experimental: Fermi-LAT has not yet been refactored to have "
+              "its API match the rest of astroquery.")
