@@ -19,12 +19,10 @@ class Conf(_config.ConfigNamespace):
     # maintain a list of URLs in case the user wants to append a mirror
     server = _config.ConfigItem(
         ['http://irsa.ipac.caltech.edu/cgi-bin/DUST/nph-dust'],
-        'Name of the irsa_dust server to use.'
-        )
+        'Name of the irsa_dust server to use.')
     timeout = _config.ConfigItem(
         30,
-        'Default timeout for connecting to server.'
-        )
+        'Default timeout for connecting to server.')
 
 conf = Conf()
 
