@@ -181,6 +181,21 @@ def _absurl_from_url(url, base_url):
 
 
 def parse_lamda_datafile(filename):
+    """
+    Read a datafile that follows the format adopted for the atomic and
+    molecular data in the LAMDA database.
+
+    Parameters
+    ----------
+    filename : str
+        Fully qualified path of the file to read.
+
+    Returns
+    -------
+    Tuple of tables: ({rateid: Table, },
+                        Table,
+                        Table)
+    """
     with open(filename) as f:
         lines = f.readlines()
     return parse_lamda_lines(lines)
@@ -228,7 +243,6 @@ def parse_lamda_lines(data):
             continue
         if 'ncoll' not in meta_coll:
             meta_coll['ncoll'] = int(_cln(line))
-            ncollrates = {ii: 0 for ii in range(1, meta_coll['ncoll'] + 1)}
             collrates = {}
             continue
         if collider is None:
