@@ -17,7 +17,8 @@ __all__ = ['Nist', 'NistClass']
 
 def _strip_blanks(table):
     """
-    Remove blank lines from table (included for "human readability" but useless to us...
+    Remove blank lines from table (included for "human readability" but
+    useless to us...
     returns a single string joined by \n newlines
 
     Parameters
@@ -40,19 +41,22 @@ def _strip_blanks(table):
 class NistClass(BaseQuery):
     URL = conf.server
     TIMEOUT = conf.timeout
-    unit_code = {'Angstrom':0,
+    unit_code = {'Angstrom': 0,
                  'nm': 1,
                  'um': 2}
-    energy_level_code = {'cm-1':0, 'invcm':0, 'cm':0,
-                'ev':1, 'eV':1, 'EV':1, 'electronvolt':1,
-                'R':2, 'Rydberg':2, 'rydberg':2}
-    order_out_code = {'wavelength':0,
-                'multiplet':1}
+    energy_level_code = {'cm-1': 0, 'invcm': 0, 'cm': 0,
+                         'ev': 1, 'eV': 1, 'EV': 1, 'electronvolt': 1,
+                         'R': 2, 'Rydberg': 2, 'rydberg': 2}
+    order_out_code = {'wavelength': 0,
+                      'multiplet': 1}
     wavelength_unit_code = {'vacuum': 3,
-                'vac+air':4}
+                            'vac+air': 4}
 
     def _args_to_payload(self, *args, **kwargs):
         """
+        Serves the same purpose as `~NistClass.query` but returns
+        the raw HTTP response rather than a `~astropy.table.Table` object.
+
         Parameters
         ----------
         minwav : `astropy.units.Quantity` object
@@ -62,9 +66,9 @@ class NistClass(BaseQuery):
         linename : str, optional
             The spectrum to fetch. Defaults to "H I"
         energy_level_unit : str, optional
-            The energy level units must be one of the following -
-            ['R', 'Rydberg', 'rydberg', 'cm', 'cm-1', 'EV', 'eV', 'electronvolt', 'ev', 'invcm']
-            Defaults to 'eV'.
+            The energy level units must be one of the following:
+            'R', 'Rydberg', 'rydberg', 'cm', 'cm-1', 'EV', 'eV',
+            'electronvolt', 'ev', 'invcm' Defaults to 'eV'.
         output_order : str, optional
             Decide ordering of output. Must be one of following:
             ['wavelength', 'multiplet']. Defaults to 'wavelength'.
@@ -78,6 +82,7 @@ class NistClass(BaseQuery):
         -------
         request_payload : dict
             The dictionary of parameters sent with the HTTP request
+
         """
         request_payload = {}
         request_payload["spectra"] = kwargs['linename']
@@ -88,14 +93,17 @@ class NistClass(BaseQuery):
         request_payload["submit"] = "Retrieve Data"
         request_payload["format"] = 1  # ascii
         request_payload["line_out"] = 0  # All lines
-        request_payload["en_unit"] = Nist.energy_level_code[kwargs["energy_level_unit"]]
+        request_payload["en_unit"] = Nist.energy_level_code[
+            kwargs["energy_level_unit"]]
         request_payload["output"] = 0  # entirely rather than pagewise
         request_payload["bibrefs"] = 1
         request_payload["show_obs_wl"] = 1
         request_payload["show_calc_wl"] = 1
-        request_payload["order_out"] = Nist.order_out_code[kwargs['output_order']]
+        request_payload["order_out"] = Nist.order_out_code[
+            kwargs['output_order']]
         request_payload["max_low_enrg"] = ""
-        request_payload["show_av"] = Nist.wavelength_unit_code[kwargs['wavelength_type']]
+        request_payload["show_av"] = Nist.wavelength_unit_code[
+            kwargs['wavelength_type']]
         request_payload["max_upp_enrg"] = ""
         request_payload["tsb_value"] = 0
         request_payload["min_str"] = ""
@@ -115,7 +123,8 @@ class NistClass(BaseQuery):
         return request_payload
 
     @prepend_docstr_noreturns("\n" + _args_to_payload.__doc__)
-    def query_async(self, minwav, maxwav, linename="H I", energy_level_unit='eV', output_order='wavelength',
+    def query_async(self, minwav, maxwav, linename="H I",
+                    energy_level_unit='eV', output_order='wavelength',
                     wavelength_type='vacuum', get_query_payload=False):
         """
         Returns
@@ -123,14 +132,15 @@ class NistClass(BaseQuery):
         response : `requests.Response` object
             The response of the HTTP request.
         """
-        request_payload = self._args_to_payload(minwav, maxwav, linename=linename,
-                                                energy_level_unit=energy_level_unit,
-                                                output_order=output_order,
-                                                wavelength_type=wavelength_type)
+        request_payload = self._args_to_payload(
+            minwav, maxwav, linename=linename,
+            energy_level_unit=energy_level_unit, output_order=output_order,
+            wavelength_type=wavelength_type)
         if get_query_payload:
             return request_payload
 
-        response = commons.send_request(Nist.URL, request_payload, Nist.TIMEOUT, request_type='GET')
+        response = commons.send_request(Nist.URL, request_payload,
+                                        Nist.TIMEOUT, request_type='GET')
         return response
 
     def _parse_result(self, response, verbose=False):
@@ -149,7 +159,7 @@ class NistClass(BaseQuery):
 
         pre_re = re.compile("<pre>(.*)</pre>", flags=re.DOTALL)
         links_re = re.compile(r"<a.*?>\s*(\w+)\s*</a>")
-        content = response.text
+        content = str(response.text)
 
         try:
             pre = pre_re.findall(content)[0]
@@ -164,11 +174,13 @@ class NistClass(BaseQuery):
         except Exception as ex:
             self.response = response
             self.table_parse_error = ex
-            raise TableParseError("Failed to parse asciitable! The raw response can be found "
-                                  "in self.response, and the error in self.table_parse_error.")
+            raise TableParseError("Failed to parse asciitable! The raw "
+                                  "response can be found in self.response, "
+                                  "and the error in self.table_parse_error.")
 
 Nist = NistClass()
 
+
 def _parse_wavelength(min_wav, max_wav):
     """
     Helper function to return wavelength and units in form accepted by NIST
