@@ -11,12 +11,13 @@ class Conf(_config.ConfigNamespace):
     """
     server = _config.ConfigItem(
         ['https://archive.nrao.edu/archive/ArchiveQuery'],
-        'Name of the NRAO mirror to use.'
-        )
+        'Name of the NRAO mirror to use.')
     timeout = _config.ConfigItem(
         60,
-        'Time limit for connecting to NRAO server.'
-        )
+        'Time limit for connecting to NRAO server.')
+    username = _config.ConfigItem(
+        "",
+        'Optional default username for ALMA archive.')
 
 conf = Conf()
 
