@@ -4,11 +4,11 @@ from ... import ogle
 import os
 import requests
 from astropy.tests.helper import pytest
-from astropy import coordinates as coord
+from astropy.coordinates import SkyCoord
 from astropy import units as u
 from ...utils.testing_tools import MockResponse
 
-DATA_FILES = {'gal_0_3':'gal_0_3.txt',
+DATA_FILES = {'gal_0_3': 'gal_0_3.txt',
               }
 
 
@@ -37,7 +37,7 @@ def test_ogle_single(patch_post):
     """
     Test a single pointing using an astropy coordinate instance
     """
-    co = coord.Galactic(0, 3, unit=(u.degree, u.degree))
+    co = SkyCoord(0, 3, unit=(u.degree, u.degree), frame='galactic')
     ogle.core.Ogle.query_region(coord=co)
 
 
@@ -45,7 +45,7 @@ def test_ogle_list(patch_post):
     """
     Test multiple pointings using a list of astropy coordinate instances
     """
-    co = coord.Galactic(0, 3, unit=(u.degree, u.degree))
+    co = SkyCoord(0, 3, unit=(u.degree, u.degree), frame='galactic')
     co_list = [co, co, co]
     ogle.core.Ogle.query_region(coord=co_list)
 
