@@ -25,6 +25,10 @@ def to_cache(response, cache_file):
         pickle.dump(response, f)
 
 
+def _replace_none_iterable(iterable):
+    return tuple('' if i is None else i for i in iterable)
+
+
 class AstroQuery(object):
 
     def __init__(self, method, url, params=None, data=None, headers=None,
@@ -60,9 +64,18 @@ class AstroQuery(object):
             request_key = (self.method, self.url)
             for k in (self.params, self.data, self.headers, self.files):
                 if isinstance(k, dict):
-                    request_key += (tuple(sorted(k.items())),)
+                    entry = (tuple(sorted(k.items(),
+                                          key=_replace_none_iterable)))
+                    entry = tuple((k_,v_.read()) if hasattr(v_,'read')
+                                  else (k_,v_) for k_,v_ in entry)
+                    for k_,v_ in entry:
+                        if hasattr(v_,'read') and hasattr(v_,'seek'):
+                            v_.seek(0)
+
+                    request_key += entry
                 elif isinstance(k, tuple) or isinstance(k, list):
-                    request_key += (tuple(sorted(k)),)
+                    request_key += (tuple(sorted(k,
+                                                 key=_replace_none_iterable)),)
                 elif k is None:
                     request_key += (None,)
                 elif isinstance(k, six.string_types):
@@ -154,6 +167,10 @@ class BaseQuery(object):
         """
         if save:
             local_filename = url.split('/')[-1]
+            if os.name == 'nt':
+                # Windows doesn't allow special characters in filenames like
+                # ":" so replace them with an underscore
+                local_filename = local_filename.replace(':', '_')
             local_filepath = os.path.join(self.cache_location or savedir or
                                           '.', local_filename)
             # REDUNDANT: spinner has this log.info("Downloading
@@ -177,6 +194,7 @@ class BaseQuery(object):
                                              stream=stream,
                                              auth=auth)
                     to_cache(response, query.request_file(self.cache_location))
+            self._last_query = query
             return response
 
     def _download_file(self, url, local_filepath, timeout=None, auth=None,
@@ -197,11 +215,11 @@ class BaseQuery(object):
             if length is not None:
                 statinfo = os.stat(local_filepath)
                 if statinfo.st_size != length:
-                    log.warn("Found cached file {0} with size {1} that is "
-                             "different from expected size {2}"
-                             .format(local_filepath,
-                                     statinfo.st_size,
-                                     length))
+                    log.warning("Found cached file {0} with size {1} that is "
+                                "different from expected size {2}"
+                                .format(local_filepath,
+                                        statinfo.st_size,
+                                        length))
                 else:
                     log.info("Found cached file {0} with expected size {1}."
                              .format(local_filepath, statinfo.st_size))
