@@ -5,11 +5,11 @@ import os
 from astropy.tests.helper import pytest
 import requests
 
-DATA_FILES = {'img':'img.fits',
-              'nid_t':'nid_t.txt',
-              'pid_t':'pid_t.txt',  # truncated to save space
-              'pos_t':'pos_t.txt',
-              'rqk_t':'rqk_t.txt',
+DATA_FILES = {'img': 'img.fits',
+              'nid_t': 'nid_t.txt',
+              'pid_t': 'pid_t.txt',  # truncated to save space
+              'pos_t': 'pos_t.txt',
+              'rqk_t': 'rqk_t.txt',
               }
 
 
@@ -21,7 +21,8 @@ def data_path(filename):
 def get_mockreturn(url, params=None, stream=False, timeout=10, **kwargs):
     if stream:
         filename = data_path(DATA_FILES['img'])
-        return MockResponse(open(filename, 'rb').read(), content_type='image/fits', **kwargs)
+        return MockResponse(open(filename, 'rb').read(),
+                            content_type='image/fits', **kwargs)
     elif params['RA'] == 163.6136:
         filename = data_path(DATA_FILES['pos_t'])
     elif params['NAIFID'] == 2003226:
