@@ -8,8 +8,9 @@ ftp://ftp.cv.nrao.edu/NRAO-staff/bkent/slap/idl/
 import warnings
 from astropy.io import ascii
 from astropy import units as u
+from astropy import log
 from ..query import BaseQuery
-from ..utils import commons, async_to_sync
+from ..utils import async_to_sync
 from ..utils.docstr_chompers import prepend_docstr_noreturns
 from . import conf
 from . import load_species_table
@@ -17,7 +18,7 @@ from . import load_species_table
 __all__ = ['Splatalogue', 'SplatalogueClass']
 
 # example query of SPLATALOGUE directly:
-# http://www.cv.nrao.edu/php/splat/c.php?sid%5B%5D=64&sid%5B%5D=108&calcIn=&data_version=v2.0&from=&to=&frequency_units=MHz&energy_range_from=&energy_range_to=&lill=on&tran=&submit=Search&no_atmospheric=no_atmospheric&no_potential=no_potential&no_probable=no_probable&include_only_nrao=include_only_nrao&displayLovas=displayLovas&displaySLAIM=displaySLAIM&displayJPL=displayJPL&displayCDMS=displayCDMS&displayToyaMA=displayToyaMA&displayOSU=displayOSU&displayRecomb=displayRecomb&displayLisa=displayLisa&displayRFI=displayRFI&ls1=ls1&ls5=ls5&el1=el1
+# http://www.cv.nrao.edu/php/splat/c.php?sid%5B%5D=64&sid%5B%5D=108&calcIn=&data_version=v3.0&from=&to=&frequency_units=MHz&energy_range_from=&energy_range_to=&lill=on&tran=&submit=Search&no_atmospheric=no_atmospheric&no_potential=no_potential&no_probable=no_probable&include_only_nrao=include_only_nrao&displayLovas=displayLovas&displaySLAIM=displaySLAIM&displayJPL=displayJPL&displayCDMS=displayCDMS&displayToyaMA=displayToyaMA&displayOSU=displayOSU&displayRecomb=displayRecomb&displayLisa=displayLisa&displayRFI=displayRFI&ls1=ls1&ls5=ls5&el1=el1
 
 
 @async_to_sync
@@ -27,7 +28,7 @@ class SplatalogueClass(BaseQuery):
     QUERY_URL = conf.query_url
     TIMEOUT = conf.timeout
     LINES_LIMIT = conf.lines_limit
-    versions = ('v1.0', 'v2.0', 'vall')
+    versions = ('v1.0', 'v2.0', 'v3.0', 'vall')
     # global constant, not user-configurable
     ALL_LINE_LISTS = ('Lovas', 'SLAIM', 'JPL', 'CDMS', 'ToyoMA', 'OSU',
                       'Recomb', 'Lisa', 'RFI')
@@ -63,6 +64,7 @@ class SplatalogueClass(BaseQuery):
         default keyword arguments (see `query_lines`) can be overridden
         here.
         """
+        super(SplatalogueClass, self).__init__()
         self.data = self._default_kwargs()
         self.set_default_options(**kwargs)
 
@@ -102,10 +104,10 @@ class SplatalogueClass(BaseQuery):
                       max_frequency=100 * u.THz,
                       chemical_name='',
                       line_lists=self.ALL_LINE_LISTS,
-                      line_strengths=('ls1', 'ls3', 'ls4', 'ls5'),
+                      line_strengths=('ls1', 'ls2', 'ls3', 'ls4', 'ls5'),
                       energy_levels=('el1', 'el2', 'el3', 'el4'),
                       exclude=('potential', 'atmospheric', 'probable'),
-                      version='v2.0',
+                      version='v3.0',
                       only_NRAO_recommended=None,
                       export=True,
                       export_limit=self.LINES_LIMIT,
@@ -128,7 +130,8 @@ class SplatalogueClass(BaseQuery):
                       show_upper_degeneracy=None, show_molecule_tag=None,
                       show_qn_code=None, show_lovas_labref=None,
                       show_lovas_obsref=None, show_orderedfreq_only=None,
-                      show_nrao_recommended=None):
+                      show_nrao_recommended=None,
+                      parse_chemistry_locally=False):
         """
         The Splatalogue service returns lines with rest frequencies in the
         range [min_frequency, max_frequency].
@@ -163,7 +166,9 @@ class SplatalogueClass(BaseQuery):
 
             ``' H2CO '`` - Just 1 species, H2CO. The spaces prevent including
                            others.
-
+        parse_chemistry_locally : bool
+            Attempt to determine the species ID #'s locally before sending the
+            query?  This will prevent queries that have no matching species.
         chem_re_flags : int
             See the `re` module
         energy_min : `None` or float
@@ -179,12 +184,14 @@ class SplatalogueClass(BaseQuery):
             The type of intensity on which to place a lower limit
         transition : str
             e.g. 1-0
-        version : ``'v1.0'`` or ``'v2.0'`` or ``'vall'``
+        version : ``'v1.0'``, ``'v2.0'``, ``'v3.0'`` or ``'vall'``
             Data version
         exclude : list
             Types of lines to exclude.  Default is:
             (``'potential'``, ``'atmospheric'``, ``'probable'``)
-            Can also exclude ``'known'``
+            Can also exclude ``'known'``.
+            To exclude nothing, use 'none', not the python object None, since
+            the latter is meant to indicate 'leave as default'
         only_NRAO_recommended : bool
             Show only NRAO recommended species?
         line_lists : list
@@ -263,10 +270,13 @@ class SplatalogueClass(BaseQuery):
             # include all
             payload['sid[]'] = []
         elif chemical_name is not None:
-            species_ids = self.get_species_ids(chemical_name, chem_re_flags)
-            if len(species_ids) == 0:
-                raise ValueError("No matching chemical species found.")
-            payload['sid[]'] = list(species_ids.values())
+            if parse_chemistry_locally:
+                species_ids = self.get_species_ids(chemical_name, chem_re_flags)
+                if len(species_ids) == 0:
+                    raise ValueError("No matching chemical species found.")
+                payload['sid[]'] = list(species_ids.values())
+            else:
+                payload['chemical_name'] = chemical_name
 
         if energy_min is not None:
             payload['energy_range_from'] = float(energy_min)
@@ -290,7 +300,12 @@ class SplatalogueClass(BaseQuery):
             raise ValueError("Invalid version specified.  Allowed versions "
                              "are {vers}".format(vers=str(self.versions)))
 
-        if exclude is not None:
+        if exclude == 'none':
+            for e in ('potential', 'atmospheric', 'probable', 'known'):
+                # Setting a keyword value to 'None' removes it (see query_lines_async)
+                log.debug("Setting no_{0} to None".format(e))
+                payload['no_' + e] = None
+        elif exclude is not None:
             for e in exclude:
                 payload['no_' + e] = 'no_' + e
 
@@ -355,7 +370,7 @@ class SplatalogueClass(BaseQuery):
 
     @prepend_docstr_noreturns("\n" + _parse_kwargs.__doc__)
     def query_lines_async(self, min_frequency=None, max_frequency=None,
-                          **kwargs):
+                          cache=True, **kwargs):
         """
 
         Returns
@@ -382,13 +397,17 @@ class SplatalogueClass(BaseQuery):
                                                    max_frequency=max_frequency,
                                                    **kwargs))
 
+        # Add an extra step: sometimes, need to REMOVE keywords
+        data_payload = {k:v for k,v in data_payload.items() if v is not None}
+
         if get_query_payload:
             return data_payload
 
-        response = commons.send_request(
-            self.QUERY_URL,
-            data_payload,
-            self.TIMEOUT)
+        response = self._request(method='POST',
+                                 url=self.QUERY_URL,
+                                 data=data_payload,
+                                 timeout=self.TIMEOUT,
+                                 cache=cache)
 
         self.response = response
 
