@@ -11,9 +11,13 @@ def append_docstr(doc):
 
 
 def prepend_docstr_noreturns(doc):
-    """ Decorator to prepend to the function's docstr after stripping out the "Returns". """
+    """
+    Decorator to prepend to the function's docstr after stripping out the
+    "Returns".
+    """
     def dec(fn):
-        fn.__doc__ = "\n".join(remove_returns(doc)) + textwrap.dedent(fn.__doc__)
+        fn.__doc__ = ("\n".join(remove_returns(doc)) +
+                      textwrap.dedent(fn.__doc__))
         return fn
     return dec
 
