@@ -17,7 +17,6 @@ from collections import OrderedDict
 import os
 from astropy.io import fits
 import astropy.utils.data as aud
-import astropy.version
 import tempfile
 
 
@@ -414,12 +413,8 @@ def test_filecontainer_save(patch_getreadablefileobj):
     ffile = commons.FileContainer(fitsfilepath, encoding='binary')
     temp_dir = tempfile.mkdtemp()
     empty_temp_file = temp_dir + os.sep + 'test_emptyfile.fits'
-    try:
-        ffile.save_fits(empty_temp_file)
-        assert os.path.exists(empty_temp_file)
-    finally:
-        os.remove(empty_temp_file)
-        os.rmdir(temp_dir)
+    ffile.save_fits(empty_temp_file)
+    assert os.path.exists(empty_temp_file)
 
 
 def test_filecontainer_get(patch_getreadablefileobj):
