@@ -7,7 +7,7 @@ from astropy.table import Table
 
 from . import conf
 from ..query import BaseQuery
-from ..utils import (commons, url_helpers,
+from ..utils import (url_helpers,
                      prepend_docstr_noreturns, async_to_sync,
                      )
 
@@ -17,8 +17,8 @@ class XMatchClass(BaseQuery):
     URL = conf.url
     TIMEOUT = conf.timeout
 
-    def query(self, cat1, cat2, max_distance, colRA1=None,
-              colDec1=None, colRA2=None, colDec2=None):
+    def query(self, cat1, cat2, max_distance, colRA1=None, colDec1=None,
+              colRA2=None, colDec2=None, cache=True, get_query_payload=False):
         """
         Query the `CDS cross-match service
         <http://cdsxmatch.u-strasbg.fr/xmatch>`_ by finding matches between
@@ -36,9 +36,9 @@ class XMatchClass(BaseQuery):
             equatorial frame and as decimal degrees numbers.
         cat2 : str or file
             Identifier of the second table. Follows the same rules as *cat1*.
-        max_distance : `~astropy.units.arcsec`
-            Maximum distance in arcsec to look for counterparts.
-            Maximum allowed value is 180.
+        max_distance : `~astropy.units.Quantity`
+            Maximum distance to look for counterparts.
+            Maximum allowed value is 180 arcsec.
         colRA1 : str
             Name of the column holding the right ascension. Only required
             if ``cat1`` is an uploaded table or a pointer to a URL.
@@ -57,18 +57,21 @@ class XMatchClass(BaseQuery):
         table : `~astropy.table.Table`
             Query results table
         """
-        response = self.query_async(
-            cat1, cat2, max_distance, colRA1, colDec1, colRA2, colDec2)
+        response = self.query_async(cat1, cat2, max_distance, colRA1, colDec1,
+                                    colRA2, colDec2, cache=cache,
+                                    get_query_payload=get_query_payload)
+        if get_query_payload:
+            return response
         return ascii.read(response.text, format='csv')
 
     @prepend_docstr_noreturns("\n" + query.__doc__)
-    def query_async(
-            self, cat1, cat2, max_distance, colRA1=None,
-            colDec1=None, colRA2=None, colDec2=None):
+    def query_async(self, cat1, cat2, max_distance, colRA1=None, colDec1=None,
+                    colRA2=None, colDec2=None, cache=True,
+                    get_query_payload=False):
         """
         Returns
         -------
-        response : `requests.Response`
+        response : `~requests.Response`
             The HTTP response returned from the service.
         """
         if max_distance > 180 * arcsec:
@@ -76,7 +79,7 @@ class XMatchClass(BaseQuery):
                 'max_distance argument must not be greater than 180')
         payload = {
             'request': 'xmatch',
-            'distMaxArcsec': max_distance.value,
+            'distMaxArcsec': max_distance.to(arcsec).value,
             'RESPONSEFORMAT': 'csv',
         }
         kwargs = {}
@@ -84,8 +87,13 @@ class XMatchClass(BaseQuery):
         self._prepare_sending_table(1, payload, kwargs, cat1, colRA1, colDec1)
         self._prepare_sending_table(2, payload, kwargs, cat2, colRA2, colDec2)
 
-        response = commons.send_request(
-            self.URL, payload, self.TIMEOUT, **kwargs)
+        if get_query_payload:
+            return payload, kwargs
+
+        response = self._request(method='POST', url=self.URL, data=payload,
+                                 timeout=self.TIMEOUT, cache=cache, **kwargs)
+        response.raise_for_status()
+
         return response
 
     def _prepare_sending_table(self, i, payload, kwargs, cat, colRA, colDec):
@@ -102,10 +110,10 @@ class XMatchClass(BaseQuery):
             fp = six.StringIO()
             cat.write(fp, format='ascii.csv')
             fp.seek(0)
-            kwargs['files'] = {catstr: fp}
+            kwargs['files'] = {catstr: ('cat1.csv', fp.read())}
         else:
             # assume it's a file-like object, support duck-typing
-            kwargs['files'] = {catstr: cat}
+            kwargs['files'] = {catstr: ('cat1.csv', cat.read())}
         if not self.is_table_available(cat):
             if ((colRA is None) or (colDec is None)):
                 raise ValueError('Specify the name of the RA/Dec columns in' +
@@ -125,7 +133,7 @@ class XMatchClass(BaseQuery):
             table_id = table_id[7:]
         return table_id in self.get_available_tables()
 
-    def get_available_tables(self):
+    def get_available_tables(self, cache=True):
         """Get the list of the VizieR tables which are available in the
         xMatch service and return them as a list of strings.
 
@@ -133,7 +141,9 @@ class XMatchClass(BaseQuery):
         response = self._request(
             'GET',
             url_helpers.urljoin_keep_path(self.URL, 'tables'),
-            {'action': 'getVizieRTableNames', 'RESPONSEFORMAT': 'txt'})
+            {'action': 'getVizieRTableNames', 'RESPONSEFORMAT': 'txt'},
+            cache=cache,
+        )
 
         content = response.text
 
